import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	jest.setTimeout(20000);
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

describe('GET /api/scans sucessfully', () => {
	it('basic get should return 200', async () => {
		const res = await axios.get(base + '/api/scans', axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('GET /api/scans illegally', () => {
	it('get for non-existant track should return 404', async () => {
		const res = await axios.get(base + '/api/scans/-1', axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('adding + getting scans', () => {
	let added_org;
	let added_runner;
	let added_scan;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organizations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('correct distance and runner input should return 200', async () => {
		const res = await axios.post(base + '/api/scans', {
			"runner": added_runner.id,
			"distance": 1000
		}, axios_config);
		added_scan = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('check if scans was added directly', async () => {
		const res = await axios.get(base + '/api/scans/' + added_scan.id, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		expect(res.data).toEqual(added_scan);
	});
	it('check if scans was added via the runner/scans endpoint.', async () => {
		const res = await axios.get(base + '/api/runners/' + added_runner.id + "/scans", axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		added_scan.runner.distance = 0;
		delete added_scan.runner.group;
		expect(res.data).toContainEqual(added_scan);
	});
});